# Eiffel

Eiffel is a neural network architecture visualization tool. it’s really simple to use. in order to start visualizing your network just insert a list of the number of nodes each layer has: e.g [2,5,5,1] –> returns a neural network with input 2 , output 1 (binary classify for example) and 2 hidden layers with 5 units each.

Eiffel is intended for educational purposes.
